/*
     This file is part of GNUnet

     GNUnet is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published
     by the Free Software Foundation; either version 2, or (at your
     option) any later version.

     GNUnet is distributed in the hope that it will be useful, but
     WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
     General Public License for more details.

     You should have received a copy of the GNU General Public License
     along with GNUnet; see the file COPYING.  If not, write to the
     Free Software Foundation, Inc., 59 Temple Place - Suite 330,
     Boston, MA 02111-1307, USA.
*/
/**
 * deleteutil, helper methods for file deletion.
 * @author Christian Grothoff
 * @file include/applications/afs/encoding/deleteutil.h
 **/

#ifndef DELETEUTIL_H
#define DELETEUTIL_H

#include "config.h"

#include "applications/afs/protocol/messages.h"

/**
 * Deletes a file under the given name into the local GNUnet node.
 *
 * @param sock the socket to use to talk to gnunetd
 * @param filename the name of the (incoming/source) file
 * @param model the delete model used to
 *        update status information; points to NULL if
 *        no status updates shall be given, otherwise 
 *        to a method that takes two size_t arguments
 *        (retrieved so far, total).
 * @param model_data pointer that is passed to the model method
 * @return OK on success, SYSERR on error
 **/
int deleteFile(GNUNET_TCP_SOCKET * sock,
	       char * filename,
	       ProgressModel model,
	       void * model_data); 


#endif
